Learn R Programming

modeltests (version 0.1.8)

check_glance_outputs: Check the output of a glance method

Description

Call this function to perform tests. If a tests fails, an informative error will be thrown. Otherwise silent.

Tests when strict = FALSE:

  • Each item passed to ... passes check_tibble()

  • Each item passed to ... has exactly 1 row.

Additional tests when strict = TRUE:

  • Column names and order agree across all elements of ....

Usage

check_glance_outputs(..., strict = TRUE)

Value

An invisible NULL. This function should be called for side effects, not return values.

Arguments

...

Outputs returned from calls to (the same) broom::glance() method.

strict

Logical indicating whether the strict version of tests should be used. Defaults to TRUE.

See Also

check_tibble()